
"""
_________________________________________________________________________________________
ScreenPoint refers to a point in the screen. All the recorded points are generated here.
You may use these objects and its methods to quickly create an automation script.
_________________________________________________________________________________________
"""

from pyautoeasy import ScreenPoint

sd = ScreenPoint(pos=(1140, 669))
sd.click_here()


asd = ScreenPoint(pos=(1089, 230))
asd.click_here()

